package Bundle::Locale::CLDR::Eurozone;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::Eurozone

=head1 CONTENTS

Locale::CLDR::Locales::Br 0.34.1
Locale::CLDR::Locales::Ca 0.34.1
Locale::CLDR::Locales::De 0.34.1
Locale::CLDR::Locales::El 0.34.1
Locale::CLDR::Locales::Es 0.34.1
Locale::CLDR::Locales::Et 0.34.1
Locale::CLDR::Locales::Eu 0.34.1
Locale::CLDR::Locales::Fi 0.34.1
Locale::CLDR::Locales::Fr 0.34.1
Locale::CLDR::Locales::Fy 0.34.1
Locale::CLDR::Locales::Ga 0.34.1
Locale::CLDR::Locales::Gl 0.34.1
Locale::CLDR::Locales::It 0.34.1
Locale::CLDR::Locales::Lb 0.34.1
Locale::CLDR::Locales::Lt 0.34.1
Locale::CLDR::Locales::Lv 0.34.1
Locale::CLDR::Locales::Mt 0.34.1
Locale::CLDR::Locales::Nl 0.34.1
Locale::CLDR::Locales::Pt 0.34.1
Locale::CLDR::Locales::Se 0.34.1
Locale::CLDR::Locales::Sk 0.34.1
Locale::CLDR::Locales::Sl 0.34.1
Locale::CLDR::Locales::Sv 0.34.1
Locale::CLDR::Locales::Tr 0.34.1
Locale::CLDR::Locales::Ast 0.34.1
Locale::CLDR::Locales::Dsb 0.34.1
Locale::CLDR::Locales::Fur 0.34.1
Locale::CLDR::Locales::Gsw 0.34.1
Locale::CLDR::Locales::Hsb 0.34.1
Locale::CLDR::Locales::Ksh 0.34.1
Locale::CLDR::Locales::Nds 0.34.1
Locale::CLDR::Locales::Smn 0.34.1
Locale::CLDR::Locales::Br::Any 0.34.1
Locale::CLDR::Locales::Ca::Any 0.34.1
Locale::CLDR::Locales::De::Any 0.34.1
Locale::CLDR::Locales::El::Any 0.34.1
Locale::CLDR::Locales::En::Any 0.34.1
Locale::CLDR::Locales::Es::Any 0.34.1
Locale::CLDR::Locales::Et::Any 0.34.1
Locale::CLDR::Locales::Eu::Any 0.34.1
Locale::CLDR::Locales::Fi::Any 0.34.1
Locale::CLDR::Locales::Fr::Any 0.34.1
Locale::CLDR::Locales::Fy::Any 0.34.1
Locale::CLDR::Locales::Ga::Any 0.34.1
Locale::CLDR::Locales::Gl::Any 0.34.1
Locale::CLDR::Locales::It::Any 0.34.1
Locale::CLDR::Locales::Lb::Any 0.34.1
Locale::CLDR::Locales::Lt::Any 0.34.1
Locale::CLDR::Locales::Lv::Any 0.34.1
Locale::CLDR::Locales::Mt::Any 0.34.1
Locale::CLDR::Locales::Nl::Any 0.34.1
Locale::CLDR::Locales::Pt::Any 0.34.1
Locale::CLDR::Locales::Se::Any 0.34.1
Locale::CLDR::Locales::Sk::Any 0.34.1
Locale::CLDR::Locales::Sl::Any 0.34.1
Locale::CLDR::Locales::Sv::Any 0.34.1
Locale::CLDR::Locales::Tr::Any 0.34.1
Locale::CLDR::Locales::Ast::Any 0.34.1
Locale::CLDR::Locales::Dsb::Any 0.34.1
Locale::CLDR::Locales::Fur::Any 0.34.1
Locale::CLDR::Locales::Gsw::Any 0.34.1
Locale::CLDR::Locales::Hsb::Any 0.34.1
Locale::CLDR::Locales::Ksh::Any 0.34.1
Locale::CLDR::Locales::Nds::Any 0.34.1
Locale::CLDR::Locales::Smn::Any 0.34.1
Locale::CLDR::Locales::Br::Any::Fr 0.34.1
Locale::CLDR::Locales::Ca::Any::Es 0.34.1
Locale::CLDR::Locales::Ca::Any::Fr 0.34.1
Locale::CLDR::Locales::Ca::Any::It 0.34.1
Locale::CLDR::Locales::De::Any::At 0.34.1
Locale::CLDR::Locales::De::Any::Be 0.34.1
Locale::CLDR::Locales::De::Any::De 0.34.1
Locale::CLDR::Locales::De::Any::It 0.34.1
Locale::CLDR::Locales::De::Any::Lu 0.34.1
Locale::CLDR::Locales::El::Any::Cy 0.34.1
Locale::CLDR::Locales::El::Any::Gr 0.34.1
Locale::CLDR::Locales::En::Any::At 0.34.1
Locale::CLDR::Locales::En::Any::Be 0.34.1
Locale::CLDR::Locales::En::Any::Cy 0.34.1
Locale::CLDR::Locales::En::Any::De 0.34.1
Locale::CLDR::Locales::En::Any::Fi 0.34.1
Locale::CLDR::Locales::En::Any::Ie 0.34.1
Locale::CLDR::Locales::En::Any::Mt 0.34.1
Locale::CLDR::Locales::En::Any::Nl 0.34.1
Locale::CLDR::Locales::En::Any::Si 0.34.1
Locale::CLDR::Locales::Es::Any::Es 0.34.1
Locale::CLDR::Locales::Et::Any::Ee 0.34.1
Locale::CLDR::Locales::Eu::Any::Es 0.34.1
Locale::CLDR::Locales::Fi::Any::Fi 0.34.1
Locale::CLDR::Locales::Fr::Any::Be 0.34.1
Locale::CLDR::Locales::Fr::Any::Fr 0.34.1
Locale::CLDR::Locales::Fr::Any::Lu 0.34.1
Locale::CLDR::Locales::Fy::Any::Nl 0.34.1
Locale::CLDR::Locales::Ga::Any::Ie 0.34.1
Locale::CLDR::Locales::Gl::Any::Es 0.34.1
Locale::CLDR::Locales::It::Any::It 0.34.1
Locale::CLDR::Locales::Lb::Any::Lu 0.34.1
Locale::CLDR::Locales::Lt::Any::Lt 0.34.1
Locale::CLDR::Locales::Lv::Any::Lv 0.34.1
Locale::CLDR::Locales::Mt::Any::Mt 0.34.1
Locale::CLDR::Locales::Nl::Any::Be 0.34.1
Locale::CLDR::Locales::Nl::Any::Nl 0.34.1
Locale::CLDR::Locales::Pt::Any::Lu 0.34.1
Locale::CLDR::Locales::Pt::Any::Pt 0.34.1
Locale::CLDR::Locales::Se::Any::Fi 0.34.1
Locale::CLDR::Locales::Sk::Any::Sk 0.34.1
Locale::CLDR::Locales::Sl::Any::Si 0.34.1
Locale::CLDR::Locales::Sv::Any::Fi 0.34.1
Locale::CLDR::Locales::Tr::Any::Cy 0.34.1
Locale::CLDR::Locales::Ast::Any::Es 0.34.1
Locale::CLDR::Locales::Dsb::Any::De 0.34.1
Locale::CLDR::Locales::En::Any::001 0.34.1
Locale::CLDR::Locales::En::Any::150 0.34.1
Locale::CLDR::Locales::Fur::Any::It 0.34.1
Locale::CLDR::Locales::Gsw::Any::Fr 0.34.1
Locale::CLDR::Locales::Hsb::Any::De 0.34.1
Locale::CLDR::Locales::Ksh::Any::De 0.34.1
Locale::CLDR::Locales::Nds::Any::De 0.34.1
Locale::CLDR::Locales::Nds::Any::Nl 0.34.1
Locale::CLDR::Locales::Smn::Any::Fi 0.34.1

=cut

1;

